@@ -1,7 +1,9 @@
-use crate::{Lerp, LinSpace, Linear};
+use crate::linspace::{Lerp, LinSpace, Linear};
 use core::ops::Range;
 use num_traits::real::Real;
 
+pub type Arange<T> = LinSpace<T>;
+
 /// Create a new iterator over the range, stepping by `step` each time
 /// This allows you to create simple float iterators
 ///
@@ -13,15 +15,26 @@ use num_traits::real::Real;
 /// println!("{:?}", it);
 /// itertools::assert_equal(it, vec![0.0, 0.5, 1.0, 1.5])
 /// ```
-pub fn arange<F>(range: Range<F>, step: F) -> LinSpace<F>
+pub fn arange<R, F>(range: R, step: F) -> Arange<F>
 where
     F: Real + Linear,
+    R: IntoArange<F>,
 {
-    let (util, steps) = arange_lerp(range, step);
-    LinSpace { x: 0, steps, util }
+    range.into_arange(step)
 }
 
-pub(crate) fn arange_lerp<F>(range: Range<F>, step: F) -> (Lerp<F>, usize)
+pub trait IntoArange<F> {
+    fn into_arange(self, step: F) -> Arange<F>;
+}
+
+impl<F: Real + Linear> IntoArange<F> for Range<F> {
+    fn into_arange(self, step: F) -> Arange<F> {
+        let (util, steps) = arange_lerp(self, step);
+        Arange { x: 0, steps, util }
+    }
+}
+
+pub fn arange_lerp<F>(range: Range<F>, step: F) -> (Lerp<F>, usize)
 where
     F: Real + Linear,
 {
